package nfa035.tp2;

/**
 * On représente une date avec un tableau de 3 entiers.
 * <ul>
 * <li>case 0 : numéro du jour
 * <li>case 1 : numéro du mois
 * <li>case 2 : numéro de l'année
 * </ul>
 * 
 * @author rosmord
 * 
 */
public class Dates {

	/**
	 * Retourne le nom du mois numéro numero.
	 * 
	 * @param numero
	 *            le numéro du mois (commence à 1)
	 * @return le nom du mois.
	 * @throws IllegalArgumentException si mois n'est pas entre 1 et 12.
	 */
	public static String nomMois(int numero) {
		if (numero < 1 || numero > 12)
			throw new IllegalArgumentException("mois hors limite "+ numero);
		String mois[]= {"janvier", "février", "mars", "avril", "mai", "juin",
				"juillet", "août", "septembre", "octobre", "novembre", "décembre"};
		return mois[numero-1];
	}

	/**
	 * Renvoie vrai si une année est bissextile.
	 * @param annee
	 * @return
	 */
	public static boolean estBissextile(int annee) {
		return annee % 400 == 0 || (annee % 4 == 0 && annee % 100 != 0);
	}

	/**
	 * retourne la représentation de la date sous forme de String.
	 * 
	 * @param date
	 * @return une représentation de date.
	 * @throws IllegalArgumentException si la date n'est pas correcte.
	 */
	public static String commeString(int[] date) {
		if (! estDateCorrecte(date))
			throw new IllegalArgumentException();
		return date[0]+ " "+ nomMois(date[1])+ " "+ date[2];
	}
	
	
	/**
	 * Retourne vrai si une date est correcte (à vous de préciser ce que ça signifie).
	 * @param date
	 * @return vrai si les trois paramètres correspondent à une vraie date.
	 */
	public static boolean estDateCorrecte(int[] date) {
		if (date.length != 3) return false;
		int jour= date[0];
		int mois= date[1];
		int annee=date[2];
		// pas d'an 0
		if (annee== 0) return false ;
		// mois compris entre 1 et 12
		if (mois< 1 || mois > 12) return false;
		// vérification du jour par rapport au mois et à l'année.
		if (jour < 1 || jour > nombreDeJoursDansMois(mois, annee))
			return false;
		return true;
	}
	
	/**
	 * Retourne le nombre de jour dans un mois pour une année donnée.
	 * @param mois
	 * @param annee
	 * @return
	 * @throws IllegalArgumentException si le numéro du mois n'est pas correct.
	 */
	public static int nombreDeJoursDansMois(int mois, int annee) {
		int nbJours[]= {31,28,31,30,31,30,31,31,30,31,30,31};
		if (mois != 2)
			return nbJours[mois-1];
		else {
			if (estBissextile(annee))
				return 29;
			else
				return 28;
		}
	}
	
	/**
	 * Retourne la date du jour suivant une date donnée
	 * @param date une date
	 * @return la date du jour suivant.
	 * @throws IllegalArgumentException si la date n'est pas correcte.
	 */
	public static int [] dateSuivante(int [] date) {
		if (! estDateCorrecte(date))
			throw new IllegalArgumentException();
		int jour= date[0];
		int mois= date[1];
		int annee= date[2];
		if (jour < nombreDeJoursDansMois(mois, annee)) {
			// on reste dans le même mois.
			return new int[]{jour+1, mois, annee};
		} else if (mois < 12) {
			// mois suivant
			return new int[] {1, mois+1, annee};
		} else {
			// année suivante
			return new int[] {1, 1, annee+1};
		}
	}
}
