package nfa035.tp2;

import static org.junit.Assert.*;

import org.junit.Test;
/**
 * Pour compléter correctement les tests:
 * <ul>
 * <li> pour chaque fonction, il faut tester 
 *  tous les cas importants, et les cas limites.
 * <li> de plus, il faut tester, les diverses configurations de cas d'erreur.
 * <li> les tests de cas d'erreur de nombreDeJoursDansMois et testDateSuivante sont laissés 
 * en exercice au lecteur intéressé.
 * </ul>
 * @author rosmord
 *
 */
public class DatesTest {

	@Test
	public void testNomMois1() {
		assertEquals("janvier", Dates.nomMois(1));
	}

	@Test
	public void testNomMois12() {
		assertEquals("décembre", Dates.nomMois(12));
	}

	@Test(expected=IllegalArgumentException.class)
	public void testNomMoisEx1() {
		 Dates.nomMois(0);
	}

	@Test(expected=IllegalArgumentException.class)
	public void testNomMoisEx2() {
		 Dates.nomMois(13);
	}

	@Test
	public void testEstBissextile2004() {
		assertTrue(Dates.estBissextile(2004));
	}

	@Test
	public void testEstBissextile2000() {
		assertTrue(Dates.estBissextile(2000));
	}

	@Test
	public void testEstBissextile1900() {
		assertFalse(Dates.estBissextile(1900));
	}

	@Test
	public void testEstBissextile2005() {
		assertFalse(Dates.estBissextile(2005));
	}

	
	@Test
	public void testCommeString() {
		assertEquals("20 mai 2014", Dates.commeString(new int[]{20,5,2014}));
	}

	@Test(expected=IllegalArgumentException.class)
	public void testCommeStringErreur() {
		Dates.commeString(new int[]{29,2,2014});
	}
	
	@Test
	public void testEstDateCorrecte() {		
		assertFalse(Dates.estDateCorrecte(new int[]{29,2,2013}));
	}

	@Test
	public void testEstDateCorrecteMauvaiseAnnee() {		
		assertFalse(Dates.estDateCorrecte(new int[]{29,1,0}));
	}
	
	@Test
	public void testEstDateCorrecteMauvaisMoisA() {		
		assertFalse(Dates.estDateCorrecte(new int[]{29,0,2000}));
	}
	
	@Test
	public void testEstDateCorrecteMauvaisMoisB() {		
		assertFalse(Dates.estDateCorrecte(new int[]{29,13,2000}));
	}

	@Test
	public void testEstDateCorrecteMauvaisJourA() {		
		assertFalse(Dates.estDateCorrecte(new int[]{0,13,2000}));
	}

	@Test
	public void testEstDateCorrecteMauvaisJourB() {		
		assertFalse(Dates.estDateCorrecte(new int[]{32,1,2000}));
	}

	
	@Test
	public void testEstDateCorrecteSimple() {		
		assertTrue(Dates.estDateCorrecte(new int[]{29,3,2012}));
	}
	
	@Test
	public void testEstDateCorrecteBissextile() {		
		assertTrue(Dates.estDateCorrecte(new int[]{29,2,2000}));
	}


	@Test
	public void testNombreDeJoursDansMois() {
		assertEquals(31, Dates.nombreDeJoursDansMois(1, 2000));
	}
	
	@Test
	public void testNombreDeJoursDansMoisFevrierB() {
		assertEquals(29, Dates.nombreDeJoursDansMois(2, 2000));
	}
	
	@Test
	public void testNombreDeJoursDansMoisFevrierNB() {
		assertEquals(28, Dates.nombreDeJoursDansMois(2, 2001));
	}
	

	@Test
	public void testAnneeSuivante() {
		assertArrayEquals(new int[] {1,2,2000},Dates.dateSuivante(new int[] {31,1,2000}));
	}
	
	@Test
	public void testDateSuivanteSimple() {
		assertArrayEquals(new int[] {11,5,2000},Dates.dateSuivante(new int[] {10,5,2000}));
	}
	
	@Test
	public void testDateSuivanteMoisSuivant() {
		assertArrayEquals(new int[] {1,6,2000},Dates.dateSuivante(new int[] {31,5,2000}));
	}

	@Test
	public void testDateSuivanteMoisSuivantBisextile() {
		assertArrayEquals(new int[] {1,3,2000},Dates.dateSuivante(new int[] {29,2,2000}));
	}


}
